@@ -1,9 +1,10 @@
 # Copyright 2016 - 2019  Ternaris.
 # SPDX-License-Identifier: AGPL-3.0-only
 
+# pylint: disable=too-many-lines
+
 import asyncio
 import code
-import datetime
 import functools
 import json
 import signal
@@ -11,6 +12,7 @@ import sqlite3
 import sys
 import traceback
 from contextlib import asynccontextmanager
+from datetime import datetime, timezone
 from functools import reduce
 from logging import getLogger
 from pathlib import Path
@@ -25,15 +27,21 @@ from tortoise.exceptions import DoesNotExist
 
 import marv_node.run
 from marv.config import ConfigError
-from marv.db import USERGROUP_REGEX, DBError, DBNotInitialized, DBPermissionError, DBVersionError
+from marv.db import (
+    USERGROUP_REGEX,
+    DBError,
+    DBNotInitializedError,
+    DBPermissionError,
+    DBVersionError,
+)
 from marv.site import SiteError, load_sitepackages, make_config
 from marv.utils import within_pyinstaller_bundle
 from marv_api import ReaderError
 from marv_api.utils import echo, err, find_obj
 from marv_cli import PDB
 from marv_cli import marv as marvcli
-from marv_node.stream import RequestedMessageTooOld
-from marv_store import DirectoryAlreadyExists
+from marv_node.stream import RequestedMessageTooOldError
+from marv_store import DirectoryAlreadyExistsError
 
 try:
     import marv_ee
@@ -65,9 +73,11 @@ def get_site_config():
     ctx = click.get_current_context()
     siteconf = ctx.obj
     if siteconf is None:
-        ctx.fail('Could not find config file: ./marv.conf or /etc/marv/marv.conf.\n'
-                 'Change working directory or specify explicitly:\n\n'
-                 '  marv --config /path/to/marv.conf\n')
+        ctx.fail(
+            'Could not find config file: ./marv.conf or /etc/marv/marv.conf.\n'
+            'Change working directory or specify explicitly:\n\n'
+            '  marv --config /path/to/marv.conf\n',
+        )
     return siteconf
 
 
@@ -76,14 +86,17 @@ async def create_site(init=None):
     siteconf = get_site_config()
     try:
         site = await Site.create(siteconf, init=init)
-    except (sqlite3.OperationalError, DBNotInitialized) as exc:
+    except (sqlite3.OperationalError, DBNotInitializedError) as exc:
         if PDB:
             raise
         err(f'{exc!r}\n\nDid you run marv init?\n', exit=1)
     except DBVersionError as exc:
-        err(f'{exc!r}\n\n'
+        err(
+            f'{exc!r}\n\n'
             'Existing database is not compatible with this version of MARV. '
-            'Check the migration instructions.', exit=1)
+            'Check the migration instructions.',
+            exit=1,
+        )
     except (ConfigError, SiteError) as exc:
         err(f'ERROR: {exc}', exit=1)
     try:
@@ -93,19 +106,24 @@ async def create_site(init=None):
 
 
 def click_async(func):
+
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
         return asyncio.run(func(*args, **kwargs))
+
+    wrapper.orig_func = func
     return wrapper
 
 
 class NoSigintArbiter(Arbiter):
+
     def handle_int(self):
         signal.signal(signal.SIGINT, lambda *_: self.kill_workers(signal.SIGKILL))
         super().handle_term()
 
 
 class GunicornApplication(BaseApplication):  # pylint: disable=abstract-method
+
     def __init__(self, app_factory, bind, certfile, keyfile, *args, **kw):
         # pylint: disable=too-many-arguments
         self.app_factory = app_factory
@@ -172,6 +190,7 @@ def marvcli_develop_server(port, public):
     """
     middlewares = []
     if PDB:
+
         @web.middleware
         async def pdb_middleware(request, handler):
             try:
@@ -190,9 +209,7 @@ def marvcli_develop_server(port, public):
     loop = asyncio.get_event_loop()
     app = loop.run_until_complete(create_app(middlewares=middlewares))
     app['debug'] = True
-    web.run_app(app,
-                host=('0.0.0.0' if public else '127.0.0.1'),
-                port=port)
+    web.run_app(app, host=('0.0.0.0' if public else '127.0.0.1'), port=port)
 
 
 @marvcli.command('serve')
@@ -217,22 +234,24 @@ def marvcli_serve(host, port, certfile, keyfile, approot):
         try:
             site = await Site.create(config)
             try:
-                application = App(site, app_root=approot).aioapp
+                return App(site, app_root=approot).aioapp
             except Exception:  # pylint: disable=broad-except
                 await site.destroy()
                 raise
-        except (sqlite3.OperationalError, DBNotInitialized) as exc:
+        except (sqlite3.OperationalError, DBNotInitializedError) as exc:
             err(f'{exc!r}\nDid you run marv init?', exit=4)
         except DBVersionError as exc:
-            err(f'{exc!r}\n'
+            err(
+                f'{exc!r}\n'
                 'Existing database is not compatible with this version of MARV. '
-                'Check the migration instructions.', exit=4)
+                'Check the migration instructions.',
+                exit=4,
+            )
         except (PermissionError, SiteError) as exc:
             err(f'ERROR: {exc}', exit=4)
         except Exception:  # pylint: disable=broad-except
             traceback.print_exc()
             sys.exit(4)
-        return application
 
     GunicornApplication(app_factory, f'{host}:{port}', certfile, keyfile).run()
 
@@ -247,7 +266,9 @@ def marvcli_serve(host, port, certfile, keyfile, approot):
     help='Delete tags',
 )
 @click.option(
-    '--confirm/--no-confirm', default=True, show_default=True,
+    '--confirm/--no-confirm',
+    default=True,
+    show_default=True,
     help='Ask for confirmation before deleting tags and comments',
 )
 @click.argument('datasets', nargs=-1, required=True)
@@ -262,10 +283,15 @@ async def marvcli_discard(datasets, tags, comments, confirm):
     Otherwise, selected data associated with the specified datasets is
     discarded right away.
     """
-    delete_related = list(filter(None, [
-        'comments' if comments else None,
-        'tags' if tags else None,
-    ]))
+    delete_related = list(
+        filter(
+            None,
+            [
+                'comments' if comments else None,
+                'tags' if tags else None,
+            ],
+        ),
+    )
     if delete_related and confirm:
         msg = ''.join(f'  - {x}\n' for x in delete_related)
         click.confirm(f'About to PERMANENTLY delete:\n{msg}Do you want to continue?', abort=True)
@@ -300,7 +326,7 @@ async def marvcli_dump(dump_file):
     siteconf = make_config(get_site_config())
     try:
         dump = await Site.Database.dump_database(siteconf.marv.dburi)
-    except DBNotInitialized as exc:
+    except DBNotInitializedError as exc:
         err(f'ERROR: {exc}', exit=1)
     except DBVersionError as exc:
         err(f'ERROR: {exc} Please use the correct version of marv to dump.', exit=1)
@@ -336,11 +362,15 @@ async def marvcli_init():
 
 @marvcli.command('query')
 @click.option(
-    '--list-tags', is_flag=True,
+    '--list-tags',
+    is_flag=True,
     help='List all tags',
 )
 @click.option(
-    '--col', '--collection', 'collections', multiple=True,
+    '--col',
+    '--collection',
+    'collections',
+    multiple=True,
     help='Limit to one or more collections or force listing of all with --collection=*',
 )
 @click.option(
@@ -348,29 +378,45 @@ async def marvcli_init():
     help='Dataset is discarded',
 )
 @click.option(
-    '--missing', is_flag=True,
+    '--missing',
+    is_flag=True,
     help='Datasets with missing files',
 )
 @click.option(
-    '--outdated', is_flag=True,
+    '--outdated',
+    is_flag=True,
     help='Datasets with outdated node output',
 )
 @click.option(
-    '--path', type=click.Path(resolve_path=True),
+    '--path',
+    type=click.Path(resolve_path=True),
     help='Dataset contains files whose path starts with PATH',
 )
 @click.option(
-    '--tagged', 'tags', multiple=True,
+    '--tagged',
+    'tags',
+    multiple=True,
     help='Match any given tag',
 )
 @click.option(
-    '-0', '--null', is_flag=True,
+    '-0',
+    '--null',
+    is_flag=True,
     help='Use null byte to separate output instead of newlines',
 )
 @click.pass_context
 @click_async
-async def marvcli_query(ctx, list_tags, collections, discarded,
-                        missing, outdated, path, tags, null):
+async def marvcli_query(
+    ctx,
+    list_tags,
+    collections,
+    discarded,
+    missing,
+    outdated,
+    path,
+    tags,
+    null,
+):
     """Query datasets.
 
     Use --col=* to list all datasets across all collections.
@@ -405,7 +451,9 @@ async def marvcli_query(ctx, list_tags, collections, discarded,
 
 @marvcli.command('run', short_help='Run nodes for DATASETS')
 @click.option(
-    '--node', 'selected_nodes', multiple=True,
+    '--node',
+    'selected_nodes',
+    multiple=True,
     help=(
         'Run individual nodes instead of all nodes used by detail and listing '
         'Use --list-nodes for a list of known nodes. Beyond that any node can be run '
@@ -413,23 +461,30 @@ async def marvcli_query(ctx, list_tags, collections, discarded,
     ),
 )
 @click.option(
-    '--list-nodes', is_flag=True,
+    '--list-nodes',
+    is_flag=True,
     help='List known nodes instead of running',
 )
 @click.option(
-    '--list-dependent', is_flag=True,
+    '--list-dependent',
+    is_flag=True,
     help='List nodes depending on selected nodes',
 )
 @click.option(
-    '--deps/--no-deps', default=True, show_default=True,
+    '--deps/--no-deps',
+    default=True,
+    show_default=True,
     help='Run dependencies of requested nodes',
 )
 @click.option(
-    '--exclude', 'excluded_nodes', multiple=True,
+    '--exclude',
+    'excluded_nodes',
+    multiple=True,
     help='Exclude individual nodes instead of running all nodes used by detail and listing',
 )
 @click.option(
-    '-f', '--force/--no-force',
+    '-f',
+    '--force/--no-force',
     help='Force run of nodes whose output is already available from store',
 )
 # TODO: force-deps is bad as it does not allow to resume
@@ -449,19 +504,26 @@ async def marvcli_query(ctx, list_tags, collections, discarded,
     help='In case of an exception keep going with remaining datasets',
 )
 @click.option(
-    '--detail/--no-detail', 'update_detail',
+    '--detail/--no-detail',
+    'update_detail',
     help='Update detail view from stored node output',
 )
 @click.option(
-    '--listing/--no-listing', 'update_listing',
+    '--listing/--no-listing',
+    'update_listing',
     help='Update listing view from stored node output',
 )
 @click.option(
-    '--cachesize', default=50, show_default=True,
+    '--cachesize',
+    default=50,
+    show_default=True,
     help='Number of messages to keep in memory for each stream',
 )
 @click.option(
-    '--col', '--collection', 'collections', multiple=True,
+    '--col',
+    '--collection',
+    'collections',
+    multiple=True,
     help='Run nodes for all datasets of selected collections, use "*" for all',
 )
 @click.argument('datasets', nargs=-1)
@@ -503,8 +565,10 @@ async def marvcli_run(  # noqa: C901
     async with create_site() as site:
         if '*' in collections:
             if selected_nodes:
-                collections = [k for k, v in site.collections.items()
-                               if set(v.nodes).issuperset(selected_nodes)]
+                collections = [
+                    k for k, v in site.collections.items()
+                    if set(v.nodes).issuperset(selected_nodes)
+                ]
                 if not collections:
                     ctx.fail('No collections have all selected nodes')
             else:
@@ -526,8 +590,10 @@ async def marvcli_run(  # noqa: C901
         if list_dependent:
             for col in (collections or sorted(site.collections.keys())):
                 click.echo(f'{col}:')
-                dependent = {x for name in selected_nodes
-                             for x in site.collections[col].nodes[name].dependent}
+                dependent = {
+                    x for name in selected_nodes
+                    for x in site.collections[col].nodes[name].dependent
+                }
                 for name in sorted(x.name for x in dependent):
                     click.echo(f'    {name}')
             return
@@ -548,27 +614,48 @@ async def marvcli_run(  # noqa: C901
 
         for setid in setids:
             if PDB:
-                await site.run(setid, selected_nodes, deps, force, keep,
-                               force_dependent, update_detail, update_listing,
-                               excluded_nodes, cachesize=cachesize)
+                await site.run(
+                    setid,
+                    selected_nodes,
+                    deps,
+                    force,
+                    keep,
+                    force_dependent,
+                    update_detail,
+                    update_listing,
+                    excluded_nodes,
+                    cachesize=cachesize,
+                )
             else:
                 try:
-                    await site.run(setid, selected_nodes, deps, force, keep,
-                                   force_dependent, update_detail, update_listing,
-                                   excluded_nodes, cachesize=cachesize)
+                    await site.run(
+                        setid,
+                        selected_nodes,
+                        deps,
+                        force,
+                        keep,
+                        force_dependent,
+                        update_detail,
+                        update_listing,
+                        excluded_nodes,
+                        cachesize=cachesize,
+                    )
                 except ConfigError as exc:
                     err(f'ERROR: {exc}', exit=1)
                 except DoesNotExist:
                     click.echo(f'ERROR: unknown {setid!r}', err=True)
                     if not keep_going:
                         raise
-                except RequestedMessageTooOld as e:
+                except RequestedMessageTooOldError as e:
                     _req = e.args[0]._requestor.node.name  # pylint: disable=no-member,protected-access
                     _handle = e.args[0].handle.node.name  # pylint: disable=no-member
-                    click.echo(f"""
+                    click.echo(
+                        f"""
     ERROR: {_req} pulled {_handle} message {e.args[1]} not being in memory anymore.
     See https://ternaris.com/marv-robotics/docs/patterns.html#reduce-separately
-    """, err=True)
+    """,
+                        err=True,
+                    )
                     ctx.abort()
                 except marv_node.run.Aborted:
                     ctx.abort()
@@ -577,13 +664,16 @@ async def marvcli_run(  # noqa: C901
                     log.error('Reader error for dataset %s: %s', setid, e)
                 except Exception as e:  # pylint: disable=broad-except
                     errors.append(setid)
-                    if isinstance(e, DirectoryAlreadyExists):
-                        click.echo(f"""
+                    if isinstance(e, DirectoryAlreadyExistsError):
+                        click.echo(
+                            f"""
     ERROR: Directory for node run already exists:
     {e.args[0]!r}
     In case no other node run is in progress, this is a bug which you are kindly
     asked to report, providing information regarding any previous, failed node runs.
-    """, err=True)
+    """,
+                            err=True,
+                        )
                         if not keep_going:
                             ctx.abort()
                     else:
@@ -613,8 +703,10 @@ async def marvcli_scan(dry_run):
 @click.option(
     '--strict',
     is_flag=True,
-    help=('By default tagging via CLI is idempotent; in strict mode it will fail if tags'
-          ' are repeatedly added or removed.'),
+    help=(
+        'By default tagging via CLI is idempotent; in strict mode it will fail if tags'
+        ' are repeatedly added or removed.'
+    ),
 )
 @click.argument('datasets', nargs=-1)
 @click.pass_context
@@ -630,8 +722,10 @@ async def marvcli_tag(ctx, add, remove, strict, datasets):
             await site.db.update_tags_by_setids(datasets, add, remove, idempotent=not strict)
         except DBPermissionError:
             if strict:
-                err('ERROR: --strict prevented add of existing or remove of non-existing tag(s).',
-                    exit=1)
+                err(
+                    'ERROR: --strict prevented add of existing or remove of non-existing tag(s).',
+                    exit=1,
+                )
             raise
 
 
@@ -665,12 +759,17 @@ async def marvcli_comment_list(datasets):
     async with create_site() as site:
         comments = await site.db.get_comments_by_setids(datasets)
         for comment in sorted(comments, key=lambda x: (x.dataset[0].setid, x.id)):
-            echo(comment.dataset[0].setid, comment.id,
-                 datetime.datetime.fromtimestamp(int(comment.time_added / 1000)),  # noqa: DTZ
-                 comment.author, repr(comment.text))
+            echo(
+                comment.dataset[0].setid,
+                comment.id,
+                datetime.fromtimestamp(int(comment.time_added / 1000), tz=timezone.utc),
+                comment.author,
+                repr(comment.text),
+            )
 
 
-SHOW_TEMPLATE = Template("""
+SHOW_TEMPLATE = Template(
+    """
 {% for dataset in datasets %}
 - name: {{ dataset.name }}
   collection: {{ dataset.collection }}
@@ -682,7 +781,10 @@ SHOW_TEMPLATE = Template("""
   {% endfor %}
 
 {% endfor %}
-""".strip(), trim_blocks=True, lstrip_blocks=True)
+""".strip(),
+    trim_blocks=True,
+    lstrip_blocks=True,
+)
 
 
 @marvcli.command('show')
@@ -697,7 +799,7 @@ async def marvcli_show(datasets):
     Some examples
       marv show setid  # show one dataset
       marv query --col=* | xargs marv show   # show all datasets
-    """
+    """  # noqa: D301
     async with create_site() as site:
         datasets = await site.db.get_datasets_by_setids(datasets, prefetch=['files'], user='::')
         yamldoc = SHOW_TEMPLATE.render(datasets=datasets)
@@ -755,14 +857,17 @@ async def marvcli_user_list():
             lambda xm_ym, x_y: (max(x_y[0], xm_ym[0]), max(x_y[1], xm_ym[1])),
             ((len(x), len(y)) for x, y in users),
         )
-        fmt = '{:%ds} | {}' % uwidth
+        fmt = f'{{:{uwidth}s}} | {{}}'
         for user, groups in users:
             click.echo(fmt.format(user, groups))
 
 
 @marvcli_user.command('pw')
 @click.option(
-    '--password', prompt=True, hide_input=True, confirmation_prompt=True,
+    '--password',
+    prompt=True,
+    hide_input=True,
+    confirmation_prompt=True,
     help='Password will be prompted',
 )
 @click.argument('username')
@@ -873,9 +978,11 @@ def ensure_python(siteconf, sitepackages):
     pyexe = Path(code.__file__).parent / 'python'
     if not pyexe.exists():
         with pyexe.open('w') as f:
-            f.write(f'#!/bin/sh\n'
-                    f'export PYTHONPATH="{sitepackages}:$PYTHONPATH"\n'
-                    f'exec {sys.executable} --config {siteconf} python "$@"')
+            f.write(
+                f'#!/bin/sh\n'
+                f'export PYTHONPATH="{sitepackages}:$PYTHONPATH"\n'
+                f'exec {sys.executable} --config {siteconf} python "$@"',
+            )
         pyexe.chmod(0o700)
     sys.executable = str(pyexe)
 
