@@ -1,6 +1,8 @@
 # Copyright 2016 - 2018  Ternaris.
 # SPDX-License-Identifier: AGPL-3.0-only
 
+from __future__ import annotations
+
 import asyncio
 import hashlib
 from base64 import b32encode
@@ -8,19 +10,25 @@ from collections import OrderedDict, namedtuple
 from contextlib import suppress
 from itertools import count, product
 from logging import getLogger
+from pathlib import Path
+from typing import TYPE_CHECKING
 
 from marv_api import dag
-from marv_api.ioctrl import NODE_SCHEMA, Abort
+from marv_api.ioctrl import NODE_SCHEMA, Abort, ResourceNotFoundError
 from marv_api.iomsgs import GetLogger, GetResourcePath
 from marv_api.utils import find_obj
 
 from . import io
 from .mixins import Keyed
 
-NODE_CACHE = {}
+if TYPE_CHECKING:
+    from typing import Any, Callable, Dict
+
+NODE_CACHE: Dict[Callable, Any] = {}
 
 
 class InputSpec(Keyed, namedtuple('InputSpec', ('name', 'value', 'foreach'))):
+
     @property
     def key(self):
         value = self.value.key if hasattr(self.value, 'key') else self.value
@@ -36,7 +44,8 @@ class InputSpec(Keyed, namedtuple('InputSpec', ('name', 'value', 'foreach'))):
         return f'<{type(self)} {foreach}{self.name}={self.value!r}>'
 
 
-class StreamSpec:  # pylint: disable=too-few-public-methods
+class StreamSpec:  # noqa: SIM119  pylint: disable=too-few-public-methods
+
     def __init__(self, node, name=None):  # pylint: disable=redefined-outer-name
         assert isinstance(node, Node)
         self.node = node
@@ -82,27 +91,45 @@ class Node(Keyed):  # pylint: disable=too-many-instance-attributes
         namespace, name = dnode.function.rsplit('.', 1)
         schema = find_obj(dnode.message_schema) if dnode.message_schema is not None else None
         inputs = dnode.inputs
-        specs = OrderedDict((
-            (name, InputSpec(name=name,
-                             value=(value if not isinstance(value, dag.Stream) else
-                                    StreamSpec(node=Node.from_dag_node(value.node),
-                                               name=value.name)),
-                             foreach=name == dnode.foreach))
-            for name, value in ((name, getattr(inputs, name)) for name in inputs.__fields__.keys())
-        ))
-        node = cls(func,
-                   schema=schema,
-                   version=dnode.version,
-                   name=name,
-                   namespace=namespace,
-                   specs=specs,
-                   group=dnode.group,
-                   dag_node=dnode)
-        NODE_CACHE[dnode] = node
-        return node
+        specs = OrderedDict(
+            (
+                (
+                    name,
+                    InputSpec(
+                        name=name,
+                        value=(
+                            value if not isinstance(value, dag.Stream) else
+                            StreamSpec(node=Node.from_dag_node(value.node), name=value.name)
+                        ),
+                        foreach=name == dnode.foreach,
+                    ),
+                ) for name, value in
+                ((name, getattr(inputs, name)) for name in inputs.__fields__.keys())  # pylint: disable=superfluous-parens
+            ),
+        )
+        NODE_CACHE[dnode] = cls(
+            func,
+            schema=schema,
+            version=dnode.version,
+            name=name,
+            namespace=namespace,
+            specs=specs,
+            group=dnode.group,
+            dag_node=dnode,
+        )
+        return NODE_CACHE[dnode]
 
-    def __init__(self, func, schema=None, version=None,
-                 name=None, namespace=None, specs=None, group=None, dag_node=None):
+    def __init__(
+        self,
+        func,
+        schema=None,
+        version=None,
+        name=None,
+        namespace=None,
+        specs=None,
+        group=None,
+        dag_node=None,
+    ):
         # pylint: disable=too-many-arguments
         # TODO: assert no default values on func, or consider default
         # values (instead of) marv.input() declarations
@@ -116,14 +143,11 @@ class Node(Keyed):  # pylint: disable=too-many-instance-attributes
         self.schema = schema
         self.specs = specs or {}
         assert group in (None, False, True, 'ondemand'), group
-        self.group = (group if group is not None else
-                      any(x.foreach for x in self.specs.values()))
+        self.group = (group if group is not None else any(x.foreach for x in self.specs.values()))
         # TODO: StreamSpec, seriously?
-        self.deps = {x.value.node for x in self.specs.values()
-                     if isinstance(x.value, StreamSpec)}
+        self.deps = {x.value.node for x in self.specs.values() if isinstance(x.value, StreamSpec)}
         self.alldeps = self.deps.copy()
-        self.alldeps.update(x for dep in self.deps
-                            for x in dep.alldeps)
+        self.alldeps.update(x for dep in self.deps for x in dep.alldeps)
 
         self.consumers = set()
         for dep in self.deps:
@@ -156,8 +180,11 @@ class Node(Keyed):  # pylint: disable=too-many-instance-attributes
             for spec in self.specs.values():
                 assert not isinstance(spec.value, Node), (self, spec.value)
                 if isinstance(spec.value, StreamSpec):
-                    value = yield io.GetStream(setid=None, node=spec.value.node,
-                                               name=spec.value.name or 'default')
+                    value = yield io.GetStream(
+                        setid=None,
+                        node=spec.value.node,
+                        name=spec.value.name or 'default',
+                    )
                     target = foreach_stream if spec.foreach else common
                 else:
                     value = spec.value
@@ -198,9 +225,10 @@ class Node(Keyed):  # pylint: disable=too-many-instance-attributes
             if inputs is None:
                 inputs = dict(common)
             qout, qin = asyncio.Queue(1), asyncio.Queue(1)
-            task = asyncio.create_task(self.execnode(key_abbrev, inputs, qin=qout, qout=qin,
-                                                     site=site),
-                                       name=key_abbrev)
+            task = asyncio.create_task(
+                self.execnode(key_abbrev, inputs, qin=qout, qout=qin, site=site),
+                name=key_abbrev,
+            )
             while True:
                 request = await qin.get()
                 if request is None:
@@ -224,7 +252,10 @@ class Node(Keyed):  # pylint: disable=too-many-instance-attributes
         log = getLogger(f'marv.node.{key_abbrev}')
         while True:
             try:
-                request = gen.send(response)
+                if isinstance(response, Exception):
+                    request = gen.throw(response)
+                else:
+                    request = gen.send(response)
             # TODO: Abort exception needs to invalidate previous node output
             except (Abort, StopIteration) as exc:
                 msg = str(exc)
@@ -241,7 +272,16 @@ class Node(Keyed):  # pylint: disable=too-many-instance-attributes
                 continue
 
             if isinstance(request, GetResourcePath):
-                response = site.config.marv.resourcedir / request.name
+                rel = Path(request.name)
+                if rel.anchor:
+                    response = ResourceNotFoundError(request.name)
+                else:
+                    basepath = site.config.marv.resourcedir
+                    fullpath = basepath.joinpath(rel).resolve()
+                    if basepath.resolve() not in fullpath.parents or not fullpath.is_file():
+                        response = ResourceNotFoundError(request.name)
+                    else:
+                        response = fullpath
                 continue
 
             qout.put_nowait(request)
