@@ -8,13 +8,15 @@ from marv_node.testing import make_dataset, run_nodes, temporary_directory
 from marv_robotics.bag import bagmeta as node
 from marv_store import Store
 
-# XXX: in what form do we need this test?
+# TODO: in what form do we need this test?
 
 
 class TestCase(marv_node.testing.TestCase):
     # TODO: Generate bags instead, but with connection info!
-    BAGS = [resource_filename('marv_node.testing._robotics_tests', 'data/test_0.bag'),
-            resource_filename('marv_node.testing._robotics_tests', 'data/test_1.bag')]
+    BAGS = [
+        resource_filename('marv_node.testing._robotics_tests', 'data/test_0.bag'),
+        resource_filename('marv_node.testing._robotics_tests', 'data/test_1.bag'),
+    ]
 
     async def test_node(self):
         with temporary_directory() as storedir:
@@ -23,4 +25,4 @@ class TestCase(marv_node.testing.TestCase):
             store.add_dataset(dataset)
             streams = await run_nodes(dataset, [node], store)
             self.assertNodeOutput(streams[0], node)
-            # XXX: test also header
+            # TODO: test also header
