@@ -8,13 +8,16 @@ async def test_tag(client, site):
     res = await client.post('/marv/api/tag', headers=client.headers, json={})
     assert res.status == 400
 
-    res = await client.post_json('/marv/api/tag', json={
-        'hodge': {
-            'add': {
-                'important': [1, 2, 3],
+    res = await client.post_json(
+        '/marv/api/tag',
+        json={
+            'hodge': {
+                'add': {
+                    'important': [1, 2, 3],
+                },
             },
         },
-    })
+    )
     assert res == {}
 
     res = await site.db.get_datasets_by_setids(await site.db.query(tags=['important']), [], '::')
